:orphan:

***********
Exceptions
***********


.. autoexception:: timeboard.OutOfBoundsError

.. autoexception:: timeboard.PartialOutOfBoundsError

.. autoexception:: timeboard.VoidIntervalError


.. autoexception:: timeboard.UnacceptablePeriodError